"""Colors configurations
"""

import numpy as np

green_color = (50, 225, 30)
blue_color = (0, 0, 255)
black_color = (0, 0, 0)
white_color = (255, 255, 255, 255)
bgcolor = np.array((11 / 255.0, 137 / 255.0, 192 / 255.0))
obstcolor = np.array([0.3, 0.3, 0.3])
goalcolor = np.array([162 / 255.0, 0, 0])
goallinecolor = 0.9 * bgcolor
nosecolor = np.array([0.3, 0.3, 0.3])
agentcolor = np.array([0.0, 1.0, 1.0])
